==> parodia_admin-1.0.2.tar.gz: lib/core/repository/ticketCategory.repository.dart <==
// POST
// /api/v1/dashboard/tickets/categories

// PUT
// /api/v1/dashboard/tickets/categories/{id}

// DELETE
// /api/v1/dashboard/tickets/categories/{id}

// POST
// /api/v1/dashboard/tickets/categories/{id}/recover
import 'package:parodia_admin/core/dto/response_item.dto.dart';
import 'package:parodia_admin/core/enums.dart';
import 'package:parodia_admin/core/http/parodia_http.dart';
import 'package:parodia_admin/core/model/body_data.model.dart';

class TicketCategoryRepository {
  ParodiaHTTP? _http;

  TicketCategoryRepository(ParodiaHTTP http) {
    _http = http;
  }

  Future<ResponseItemDTO> create({TicketCategoryBody? ticketCategory}) async {
    final response = await _http!.request(
      requestType: RequestType.post,
      path: '/tickets/categories',
      data: ticketCategory,
    );

    return ResponseItemDTO(
      response: response,
      fromJson: null,
    );
  }

  Future<ResponseItemDTO> update({String? id, TicketCategoryBody? ticketCategory}) async {
    final response = await _http!.request(
      requestType: RequestType.put,
      path: '/tickets/categories',
      param: id,
      data: ticketCategory,
    );

    return ResponseItemDTO(
      response: response,
      fromJson: null,
    );
  }

  Future<ResponseItemDTO> delete({String? id}) async {
    final response = await _http!.request(
      requestType: RequestType.delete,
      path: '/tickets/categories',
      param: id,
    );

    return ResponseItemDTO(
      response: response,
      fromJson: null,
    );
  }

  Future<ResponseItemDTO> recover({String? id}) async {
    final response = await _http!.request(
      requestType: RequestType.post,
      path: '/tickets/categories/$id/recover',
    );

    return ResponseItemDTO(
      response: response,
      fromJson: null,
    );
  }
}

==> parodia_admin-1.0.20.tar.gz: lib/core/repository/ticketCategory.repository.dart <==
// POST
// /api/v1/dashboard/dashboard/tickets/categories

// PUT
// /api/v1/dashboard/dashboard/tickets/categories/{id}

// DELETE
// /api/v1/dashboard/dashboard/tickets/categories/{id}

// POST
// /api/v1/dashboard/dashboard/tickets/categories/{id}/recover
import 'package:parodia_admin/core/dto/response_item.dto.dart';
import 'package:parodia_admin/core/enums.dart';
import 'package:parodia_admin/core/http/parodia_http.dart';
import 'package:parodia_admin/core/model/body_data.model.dart';

class TicketCategoryRepository {
  ParodiaHTTP? _http;

  TicketCategoryRepository(ParodiaHTTP http) {
    _http = http;
  }

  Future<ResponseItemDTO> create({TicketCategoryBody? ticketCategory}) async {
    final response = await _http!.request(
      requestType: RequestType.post,
      path: '/dashboard/tickets/categories',
      data: ticketCategory,
    );

    return ResponseItemDTO(
      response: response,
      fromJson: null,
    );
  }

  Future<ResponseItemDTO> update({String? id, TicketCategoryBody? ticketCategory}) async {
    final response = await _http!.request(
      requestType: RequestType.put,
      path: '/dashboard/tickets/categories',
      param: id,
      data: ticketCategory,
    );

    return ResponseItemDTO(
      response: response,
      fromJson: null,
    );
  }

  Future<ResponseItemDTO> delete({String? id}) async {
    final response = await _http!.request(
      requestType: RequestType.delete,
      path: '/dashboard/tickets/categories',
      param: id,
    );

    return ResponseItemDTO(
      response: response,
      fromJson: null,
    );
  }

  Future<ResponseItemDTO> recover({String? id}) async {
    final response = await _http!.request(
      requestType: RequestType.post,
      path: '/dashboard/tickets/categories/$id/recover',
    );

    return ResponseItemDTO(
      response: response,
      fromJson: null,
    );
  }
}
